@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-package PDL::Stats;
+#package PDL::Stats;
 
 =head1 NAME
 
@@ -8,11 +8,13 @@ PDL::Stats - a collection of statistics modules in Perl Data Language, with a qu
 
 =head1 VERSION
 
-Version 0.4.1
+Version 0.4.2
 
 =cut
 
-$VERSION = '0.4.1';
+$VERSION = '0.4.2';
+
+$PDL::onlinedoc->scan(__FILE__) if $PDL::onlinedoc;
 
 
 =head1 DESCRIPTION
